@@ -11,58 +11,58 @@ lattice.options(default.theme = standard.theme(color = FALSE))
 
 
 ###################################################
-### code chunk number 2: ChainLadder.Rnw:219-220 (eval = FALSE)
+### code chunk number 2: ChainLadder.Rnw:213-214 (eval = FALSE)
 ###################################################
 ## demo(package="ChainLadder")
 
 
 ###################################################
-### code chunk number 3: ChainLadder.Rnw:223-225 (eval = FALSE)
+### code chunk number 3: ChainLadder.Rnw:217-219 (eval = FALSE)
 ###################################################
 ## library(ChainLadder)
 ## demo("demo name")
 
 
 ###################################################
-### code chunk number 4: ChainLadder.Rnw:234-235 (eval = FALSE)
+### code chunk number 4: ChainLadder.Rnw:228-229 (eval = FALSE)
 ###################################################
 ## install.packages('ChainLadder') 
 
 
 ###################################################
-### code chunk number 5: ChainLadder.Rnw:240-241
+### code chunk number 5: ChainLadder.Rnw:234-235
 ###################################################
 library(ChainLadder)
 
 
 ###################################################
-### code chunk number 6: ChainLadder.Rnw:243-244 (eval = FALSE)
+### code chunk number 6: ChainLadder.Rnw:237-238 (eval = FALSE)
 ###################################################
 ## library(ChainLadder)
 
 
 ###################################################
-### code chunk number 7: ChainLadder.Rnw:246-247
+### code chunk number 7: ChainLadder.Rnw:240-241
 ###################################################
 cat(ChainLadder:::chainladderWelcomeMessage())
 
 
 ###################################################
-### code chunk number 8: ChainLadder.Rnw:271-273 (eval = FALSE)
+### code chunk number 8: ChainLadder.Rnw:265-267 (eval = FALSE)
 ###################################################
 ## require(ChainLadder)
 ## data(package="ChainLadder")
 
 
 ###################################################
-### code chunk number 9: ChainLadder.Rnw:278-280
+### code chunk number 9: ChainLadder.Rnw:272-274
 ###################################################
 ## Sample triangle
 RAA
 
 
 ###################################################
-### code chunk number 10: ChainLadder.Rnw:307-308 (eval = FALSE)
+### code chunk number 10: ChainLadder.Rnw:301-302 (eval = FALSE)
 ###################################################
 ## plot(RAA)
 
@@ -74,7 +74,7 @@ plot(RAA)
 
 
 ###################################################
-### code chunk number 12: ChainLadder.Rnw:327-328 (eval = FALSE)
+### code chunk number 12: ChainLadder.Rnw:321-322 (eval = FALSE)
 ###################################################
 ## plot(RAA, lattice=TRUE)
 
@@ -86,13 +86,13 @@ plot(RAA, lattice=TRUE)
 
 
 ###################################################
-### code chunk number 14: ChainLadder.Rnw:348-349 (eval = FALSE)
+### code chunk number 14: ChainLadder.Rnw:342-343 (eval = FALSE)
 ###################################################
 ## ?plot.triangle
 
 
 ###################################################
-### code chunk number 15: ChainLadder.Rnw:357-363
+### code chunk number 15: ChainLadder.Rnw:351-357
 ###################################################
 raa.inc <- cum2incr(RAA)
 ## Show first origin period and its incremental development
@@ -103,13 +103,35 @@ raa.cum[1,]
 
 
 ###################################################
-### code chunk number 16: ChainLadder.Rnw:375-376 (eval = FALSE)
+### code chunk number 16: ChainLadder.Rnw:382-393 (eval = FALSE)
+###################################################
+## myCSVfile <- "path/to/folder/with/triangle.csv"
+## ## Use the R command: 
+## # myCSVfile <- file.choose() 
+## ## to select the file interactively
+## tri <- read.csv(file=myCSVfile, header = FALSE) 
+## ## Use read.csv2 if semicolons are used as a separator likely  
+## ## to be the case if you are in continental Europe
+## library(ChainLadder)
+## ## Convert to triangle
+## tri <- as.triangle(as.matrix(tri))
+## # Job done.
+
+
+###################################################
+### code chunk number 17: ChainLadder.Rnw:402-403 (eval = FALSE)
+###################################################
+## tri <- read.table(file="clipboard", sep="\t", na.strings="")
+
+
+###################################################
+### code chunk number 18: ChainLadder.Rnw:414-415 (eval = FALSE)
 ###################################################
 ## demo(DatabaseExamples)
 
 
 ###################################################
-### code chunk number 17: ChainLadder.Rnw:393-399
+### code chunk number 19: ChainLadder.Rnw:432-438
 ###################################################
 filename <-  file.path(system.file("Database", 
                                    package="ChainLadder"), 
@@ -120,14 +142,14 @@ summary(myData)
 
 
 ###################################################
-### code chunk number 18: ChainLadder.Rnw:402-404
+### code chunk number 20: ChainLadder.Rnw:441-443
 ###################################################
 raa <- subset(myData, lob %in% "RAA")
 head(raa)
 
 
 ###################################################
-### code chunk number 19: ChainLadder.Rnw:410-415
+### code chunk number 21: ChainLadder.Rnw:449-454
 ###################################################
 raa.tri <- as.triangle(raa, 
                        origin="origin", 
@@ -137,26 +159,14 @@ raa.tri
 
 
 ###################################################
-### code chunk number 20: ChainLadder.Rnw:422-424
+### code chunk number 22: ChainLadder.Rnw:461-463
 ###################################################
 raa.df <- as.data.frame(raa.tri, na.rm=TRUE)
 head(raa.df)
 
 
 ###################################################
-### code chunk number 21: ChainLadder.Rnw:443-444 (eval = FALSE)
-###################################################
-## x <- read.table(file="clipboard", sep="\t", na.strings="")
-
-
-###################################################
-### code chunk number 22: ChainLadder.Rnw:449-450 (eval = FALSE)
-###################################################
-## write.table(RAA, file="clipboard", sep="\t", na="")
-
-
-###################################################
-### code chunk number 23: ChainLadder.Rnw:470-477
+### code chunk number 23: ChainLadder.Rnw:490-497
 ###################################################
 n <- 10
 f <- sapply(1:(n-1), 
@@ -168,7 +178,7 @@ f
 
 
 ###################################################
-### code chunk number 24: ChainLadder.Rnw:483-492
+### code chunk number 24: ChainLadder.Rnw:503-512
 ###################################################
 dev.period <- 1:(n-1)
 plot(log(f-1) ~ dev.period, main="Log-linear extrapolation of age-to-age factors")
@@ -182,7 +192,7 @@ f.tail
 
 
 ###################################################
-### code chunk number 25: ChainLadder.Rnw:497-500
+### code chunk number 25: ChainLadder.Rnw:517-520
 ###################################################
 plot(100*(rev(1/cumprod(rev(c(f, tail[tail>1.0001]))))), t="b",
      main="Expected claims development pattern",
@@ -190,7 +200,7 @@ plot(100*(rev(1/cumprod(rev(c(f, tail[tail>1.0001]))))), t="b",
 
 
 ###################################################
-### code chunk number 26: ChainLadder.Rnw:509-515
+### code chunk number 26: ChainLadder.Rnw:529-535
 ###################################################
 f <- c(f, f.tail)
 fullRAA <- cbind(RAA, Ult = rep(0, 10))
@@ -201,13 +211,13 @@ round(fullRAA)
 
 
 ###################################################
-### code chunk number 27: ChainLadder.Rnw:519-520
+### code chunk number 27: ChainLadder.Rnw:539-540
 ###################################################
 sum(fullRAA[ ,11] - getLatestCumulative(RAA))
 
 
 ###################################################
-### code chunk number 28: ChainLadder.Rnw:543-559
+### code chunk number 28: ChainLadder.Rnw:563-579
 ###################################################
 linkratios <- c(attr(ata(RAA), "vwtd"), tail = 1.05)
 round(linkratios, 3) # display to only three decimal places
@@ -228,7 +238,7 @@ Exhibit
 
 
 ###################################################
-### code chunk number 29: ChainLadder.Rnw:568-573
+### code chunk number 29: ChainLadder.Rnw:588-593
 ###################################################
 lmCL <- function(i, Triangle){
   lm(y~x+0, weights=1/Triangle[,i],
@@ -238,14 +248,14 @@ sapply(lapply(c(1:(n-1)), lmCL, RAA), coef)
 
 
 ###################################################
-### code chunk number 30: ChainLadder.Rnw:613-615
+### code chunk number 30: ChainLadder.Rnw:633-635
 ###################################################
 mack <- MackChainLadder(RAA, est.sigma="Mack")
 mack
 
 
 ###################################################
-### code chunk number 31: ChainLadder.Rnw:618-620
+### code chunk number 31: ChainLadder.Rnw:638-640
 ###################################################
 mack$f
 mack$FullTriangle
@@ -264,7 +274,7 @@ plot(mack, lattice=TRUE)
 
 
 ###################################################
-### code chunk number 34: ChainLadder.Rnw:649-660
+### code chunk number 34: ChainLadder.Rnw:669-680
 ###################################################
 MCLpaid
 MCLincurred
@@ -280,7 +290,7 @@ plot(MCL)
 
 
 ###################################################
-### code chunk number 35: ChainLadder.Rnw:677-681
+### code chunk number 35: ChainLadder.Rnw:697-701
 ###################################################
 ## See also the example in section 8 of England & Verrall (2002) 
 ## on page 55.
@@ -289,19 +299,19 @@ B
 
 
 ###################################################
-### code chunk number 36: ChainLadder.Rnw:685-686
+### code chunk number 36: ChainLadder.Rnw:705-706
 ###################################################
 plot(B)
 
 
 ###################################################
-### code chunk number 37: ChainLadder.Rnw:692-693
+### code chunk number 37: ChainLadder.Rnw:712-713
 ###################################################
 quantile(B, c(0.75,0.95,0.99, 0.995))
 
 
 ###################################################
-### code chunk number 38: ChainLadder.Rnw:697-705
+### code chunk number 38: ChainLadder.Rnw:717-725
 ###################################################
 ## fit a distribution to the IBNR
 library(MASS)
@@ -314,46 +324,46 @@ curve(plnorm(x,fit$estimate["meanlog"], fit$estimate["sdlog"]),
 
 
 ###################################################
-### code chunk number 39: ChainLadder.Rnw:763-764
+### code chunk number 39: ChainLadder.Rnw:783-784
 ###################################################
 str(liab)
 
 
 ###################################################
-### code chunk number 40: ChainLadder.Rnw:767-769
+### code chunk number 40: ChainLadder.Rnw:787-789
 ###################################################
 liab2 <- as(liab, "triangles")
 class(liab2)
 
 
 ###################################################
-### code chunk number 41: ChainLadder.Rnw:772-773 (eval = FALSE)
+### code chunk number 41: ChainLadder.Rnw:792-793 (eval = FALSE)
 ###################################################
 ## showMethods(classes = "triangles")
 
 
 ###################################################
-### code chunk number 42: ChainLadder.Rnw:777-779
+### code chunk number 42: ChainLadder.Rnw:797-799
 ###################################################
 # use drop = TRUE to remove rows that are all NA's
 liab2[, 12:14, drop = TRUE]
 
 
 ###################################################
-### code chunk number 43: ChainLadder.Rnw:782-783
+### code chunk number 43: ChainLadder.Rnw:802-803
 ###################################################
 cbind2(liab2[1:3, 12])
 
 
 ###################################################
-### code chunk number 44: ChainLadder.Rnw:796-798
+### code chunk number 44: ChainLadder.Rnw:816-818
 ###################################################
 fit1 <- MultiChainLadder(liab, fit.method = "OLS")
 lapply(summary(fit1)$report.summary, "[", 15, )
 
 
 ###################################################
-### code chunk number 45: ChainLadder.Rnw:812-815
+### code chunk number 45: ChainLadder.Rnw:832-835
 ###################################################
 fit <- lapply(liab, MackChainLadder, est.sigma = "Mack")
 # the same as the first triangle above
@@ -361,33 +371,33 @@ lapply(fit, function(x) t(summary(x)$Totals))
 
 
 ###################################################
-### code chunk number 46: ChainLadder.Rnw:827-829
+### code chunk number 46: ChainLadder.Rnw:847-849
 ###################################################
 (B1 <- MultiChainLadder(list(GenIns), fit.method = "OLS", 
     mse.method = "Independence"))
 
 
 ###################################################
-### code chunk number 47: ChainLadder.Rnw:838-840
+### code chunk number 47: ChainLadder.Rnw:858-860
 ###################################################
 fit2 <- MultiChainLadder(liab, fit.method = "SUR")
 lapply(summary(fit2)$report.summary, "[", 15, )
 
 
 ###################################################
-### code chunk number 48: ChainLadder.Rnw:847-848
+### code chunk number 48: ChainLadder.Rnw:867-868
 ###################################################
 round(unlist(residCor(fit2)), 3)
 
 
 ###################################################
-### code chunk number 49: ChainLadder.Rnw:855-856
+### code chunk number 49: ChainLadder.Rnw:875-876
 ###################################################
 do.call("rbind", coef(fit2))
 
 
 ###################################################
-### code chunk number 50: ChainLadder.Rnw:864-868 (eval = FALSE)
+### code chunk number 50: ChainLadder.Rnw:884-888 (eval = FALSE)
 ###################################################
 ## parold <- par(mfrow = c(4, 2), mar = c(4, 4, 2, 1), 
 ##     mgp = c(1.3, 0.3, 0), tck = -0.02)
@@ -405,15 +415,16 @@ par(parold)
 
 
 ###################################################
-### code chunk number 52: ChainLadder.Rnw:930-933
+### code chunk number 52: ChainLadder.Rnw:950-954
 ###################################################
+require(systemfit)
 W1 <- MultiChainLadder2(liab, mse.method = "Independence", 
       	control = systemfit.control(methodResidCov = "Theil"))
 lapply(summary(W1)$report.summary, "[", 15, )
 
 
 ###################################################
-### code chunk number 53: ChainLadder.Rnw:939-946
+### code chunk number 53: ChainLadder.Rnw:960-967
 ###################################################
 for (i in 1:5){
   W2 <- MultiChainLadder2(liab, mse.method = "Independence", 
@@ -425,13 +436,13 @@ lapply(summary(W2)$report.summary, "[", 15, )
 
 
 ###################################################
-### code chunk number 54: ChainLadder.Rnw:965-966
+### code chunk number 54: ChainLadder.Rnw:986-987
 ###################################################
 str(auto)
 
 
 ###################################################
-### code chunk number 55: ChainLadder.Rnw:970-974
+### code chunk number 55: ChainLadder.Rnw:991-995
 ###################################################
 f0 <- MultiChainLadder2(auto, type = "MCL")
 # show correlation- the last three columns have zero correlation
@@ -440,7 +451,7 @@ print(do.call(cbind, residCor(f0)), digits = 3)
 
 
 ###################################################
-### code chunk number 56: ChainLadder.Rnw:983-984
+### code chunk number 56: ChainLadder.Rnw:1004-1005
 ###################################################
 f1 <- MultiChainLadder2(auto, type = "MCL+int")
 
@@ -456,20 +467,20 @@ par(parold)
 
 
 ###################################################
-### code chunk number 58: ChainLadder.Rnw:1010-1011
+### code chunk number 58: ChainLadder.Rnw:1031-1032
 ###################################################
 lapply(summary(f1, portfolio = "1+3")@report.summary, "[", 11, )
 
 
 ###################################################
-### code chunk number 59: ChainLadder.Rnw:1020-1022
+### code chunk number 59: ChainLadder.Rnw:1041-1043
 ###################################################
 ult <- summary(f1)$Ultimate
 print(ult[, 1] /ult[, 2], 3)
 
 
 ###################################################
-### code chunk number 60: ChainLadder.Rnw:1033-1049
+### code chunk number 60: ChainLadder.Rnw:1054-1070
 ###################################################
 da <- auto[1:2]
 # MCL with diagonal development
@@ -490,19 +501,19 @@ print(do.call(cbind, c(r1, list(MuCl = r2))) * 100, digits = 4)
 
 
 ###################################################
-### code chunk number 61: ChainLadder.Rnw:1101-1102
+### code chunk number 61: ChainLadder.Rnw:1122-1123
 ###################################################
 ClarkLDF(RAA)
 
 
 ###################################################
-### code chunk number 62: ChainLadder.Rnw:1112-1113
+### code chunk number 62: ChainLadder.Rnw:1133-1134
 ###################################################
 ClarkLDF(RAA, maxage = 20)
 
 
 ###################################################
-### code chunk number 63: ChainLadder.Rnw:1117-1118
+### code chunk number 63: ChainLadder.Rnw:1138-1139
 ###################################################
 ClarkLDF(RAA, G="weibull")
 
@@ -514,7 +525,7 @@ plot(ClarkLDF(RAA, G="weibull"))
 
 
 ###################################################
-### code chunk number 65: ChainLadder.Rnw:1146-1147
+### code chunk number 65: ChainLadder.Rnw:1167-1168
 ###################################################
 ClarkCapeCod(RAA, Premium = 40000, G = "weibull")
 
@@ -526,7 +537,7 @@ plot(ClarkCapeCod(RAA, Premium = 40000, G = "weibull"))
 
 
 ###################################################
-### code chunk number 67: ChainLadder.Rnw:1204-1209
+### code chunk number 67: ChainLadder.Rnw:1225-1230
 ###################################################
 # load data 
 data(GenIns)
@@ -536,13 +547,13 @@ GenIns <- GenIns / 1000
 
 
 ###################################################
-### code chunk number 68: ChainLadder.Rnw:1213-1214
+### code chunk number 68: ChainLadder.Rnw:1234-1235
 ###################################################
 summary(fit1, type = "model")
 
 
 ###################################################
-### code chunk number 69: ChainLadder.Rnw:1219-1223
+### code chunk number 69: ChainLadder.Rnw:1240-1244
 ###################################################
 # Gamma GLM
 (fit2 <- glmReserve(GenIns, var.power = 2))
@@ -551,20 +562,20 @@ summary(fit1, type = "model")
 
 
 ###################################################
-### code chunk number 70: ChainLadder.Rnw:1231-1233
+### code chunk number 70: ChainLadder.Rnw:1252-1254
 ###################################################
 set.seed(11)
 (fit5 <- glmReserve(GenIns, mse.method = "boot"))
 
 
 ###################################################
-### code chunk number 71: ChainLadder.Rnw:1240-1241
+### code chunk number 71: ChainLadder.Rnw:1261-1262
 ###################################################
 names(fit5)
 
 
 ###################################################
-### code chunk number 72: ChainLadder.Rnw:1246-1250
+### code chunk number 72: ChainLadder.Rnw:1267-1271
 ###################################################
 pr <- as.data.frame(fit5$sims.reserve.pred)
 qv <- c(0.025, 0.25, 0.5, 0.75, 0.975)
@@ -573,7 +584,7 @@ print(format(round(res.q), big.mark = ","), quote = FALSE)
 
 
 ###################################################
-### code chunk number 73: ChainLadder.Rnw:1256-1265 (eval = FALSE)
+### code chunk number 73: ChainLadder.Rnw:1277-1286 (eval = FALSE)
 ###################################################
 ## library(ggplot2)
 ## library(reshape2)
@@ -587,7 +598,27 @@ print(format(round(res.q), big.mark = ","), quote = FALSE)
 
 
 ###################################################
-### code chunk number 74: ChainLadder.Rnw:1322-1325
+### code chunk number 74: ChainLadder.Rnw:1350-1353
+###################################################
+library(ChainLadder)
+PIC <- PaidIncurredChain(USAApaid, USAAincurred)
+PIC
+
+
+###################################################
+### code chunk number 75: ChainLadder.Rnw:1357-1358
+###################################################
+PIC$Res.Origin
+
+
+###################################################
+### code chunk number 76: ChainLadder.Rnw:1361-1362
+###################################################
+PIC$Res.Tot
+
+
+###################################################
+### code chunk number 77: ChainLadder.Rnw:1419-1422
 ###################################################
 M <- MackChainLadder(MW2014, est.sigma="Mack")
 cdrM <- CDR(M)
@@ -595,7 +626,14 @@ round(cdrM, 1)
 
 
 ###################################################
-### code chunk number 75: tweedieReserve (eval = FALSE)
+### code chunk number 78: ChainLadder.Rnw:1427-1429
+###################################################
+cdrAll <- CDR(M,dev="all")
+round(cdrAll, 1)
+
+
+###################################################
+### code chunk number 79: tweedieReserve (eval = FALSE)
 ###################################################
 ##  p_profile <- tweedieReserve(MW2008, p.optim=TRUE, 
 ##    p.check=c(0,1.1,1.2,1.3,1.4,1.5,2,3),
@@ -613,19 +651,19 @@ round(cdrM, 1)
 
 
 ###################################################
-### code chunk number 76: ChainLadder.Rnw:1421-1422 (eval = FALSE)
+### code chunk number 80: ChainLadder.Rnw:1525-1526 (eval = FALSE)
 ###################################################
 ## system.file("Excel", package="ChainLadder") 
 
 
 ###################################################
-### code chunk number 77: ChainLadder.Rnw:1430-1431 (eval = FALSE)
+### code chunk number 81: ChainLadder.Rnw:1534-1535 (eval = FALSE)
 ###################################################
 ## system.file("SWord", package="ChainLadder") 
 
 
 ###################################################
-### code chunk number 78: ChainLadder.Rnw:1436-1437 (eval = FALSE)
+### code chunk number 82: ChainLadder.Rnw:1540-1541 (eval = FALSE)
 ###################################################
 ## demo(package="ChainLadder")
 
